@@ -152,7 +152,8 @@ class DetailsWindow(hildon.StackableWindow):
                 print "add reference error",e
 
     def on_call_clicked(self,w,tel):
-        os.system("dbus-send --system --dest=com.nokia.csd.Call --type=method_call --print-reply /com/nokia/csd/call com.nokia.csd.Call.CreateWith string:\"%s\" uint32:0 &" % tel )
+        #os.system(  "dbus-send --system --dest=com.nokia.csd.Call --type=method_call --print-reply /com/nokia/csd/call com.nokia.csd.Call.CreateWith string:\"%s\" uint32:0 &" % tel )
+        os.system(  "dbus-send --system --type=method_call --print-reply --dest=com.nokia.csd.Call /com/nokia/csd/call com.nokia.csd.Call.CreateWith string:\"%s\" uint32:0" % tel.replace(" ", "") )
 
     def on_route_to_it(self, w, lat, lon):
         p = None
