@@ -275,8 +275,8 @@ class YosmapaOSD(gobject.GObject, osmgpsmap.GpsMapLayer):
             elif gdkeventbutton.y>(self.size[1]-100) and  gdkeventbutton.y<(self.size[1]-34):
                 print "bt menu"
                 dialog = MainMenuDialog(self.osmMapa, CONFIG, maps_source,autorotate, FremantleRotation)
-                dialog.run()
-                dialog.destroy()
+                #dialog.run()
+                #dialog.destroy()
                 #print "response from dialog [",res,"]"
 
         elif gdkeventbutton.x <= 52:
@@ -311,11 +311,28 @@ class YosmapaOSD(gobject.GObject, osmgpsmap.GpsMapLayer):
                             except:
                                 pass
 
-                            md = hildon.Dialog()
-                            md.set_title( plugin_name )
-                            w2 = plugin[0].get_menu_widgets(md)
-                            md.vbox.pack_start( w2, True )
-                            md.show_all()
+                            stackW = 0
+                            try:
+                                if plugin[0].ui_stackable:
+                                    stackW = 1
+                            except:
+                                pass
+
+                            if stackW == 0:
+                                md = hildon.Dialog()
+                                md.set_title( plugin_name )
+                                w2 = plugin[0].get_menu_widgets(md)
+                                md.vbox.pack_start( w2, True )
+                                md.show_all()
+                            else:
+                                w = hildon.StackableWindow()
+                                self.osmMapa.set_autorotate_for_object(w)
+                                w.set_title( plugin_name )
+                                v = gtk.VBox()
+                                w2 = plugin[0].get_menu_widgets(w)
+                                v.pack_start(w2, True)
+                                w.add( v )
+                                w.show_all()
                             #md.run()
                         if w <> None:
                             plug_nr+=1
@@ -418,7 +435,7 @@ gobject.type_register(YosmapaOSD)
 
 
 
-class UI(gtk.Window):
+class UI(hildon.StackableWindow):
 
     def dont_sleep(self):
         f = open( "/sys/class/backlight/acx565akm/brightness", "r")
@@ -451,6 +468,8 @@ class UI(gtk.Window):
 
     def get_config(self):
         return CONFIG
+    def get_version(self):
+        return version
 
     def set_autorotate_for_object_same_as_UI(self, obj):
         try:
@@ -497,7 +516,7 @@ class UI(gtk.Window):
     def __init__(self):
         self.window_is_fullscreen = False
 
-        gtk.Window.__init__(self, gtk.WINDOW_TOPLEVEL)
+        hildon.StackableWindow.__init__(self)
         self.connect('key-release-event', self.on_key_down)
 
         self.ben_iter = 100
